#pragma once

// Defines the plotting mode.
enum VDC_PLOT_MODE {
	VDC_PLOT_MODE_SET,    // Pixels are set.
	VDC_PLOT_MODE_CLEAR,  // Pixels are cleared.
	VDC_PLOT_MODE_INVERT, // Pixels are inverted.
};

// Clear the LCD.
void vdc_clear(void);

// Set the current plotting mode.
void vdc_set_plot_mode(enum VDC_PLOT_MODE mode);

// Set a pixel on the LCD.
void vdc_set_pixel(int x, int y);

// Clear a pixel on the LCD.
void vdc_clear_pixel(int x, int y);

// Invert a pixel on the LCD.
void vdc_invert_pixel(int x, int y);

// Draw a pixel on the LCD using the current plotting mode.
extern void (*vdc_draw_pixel)(int, int);

// Draw a line on the LCD.
// Adapted from http://en.wikipedia.org/wiki/Bresenham's_line_algorithm
void vdc_draw_line(int x0, int y0, int x1, int y1);

// Draw a circle on the LCD.
// Adapted from http://en.wikipedia.org/wiki/Midpoint_circle_algorithm
void vdc_draw_circle(int x0, int y0, int radius);

// Prints a character on the LCD at the current cursor position.
void vdc_put_map(char c);

// Moves the text cursor right one character. If the cursor moves outside the text viewport it is moved back to the leftmost column and down a line.
void vdc_cursor_right(void);

// Moves the text cursor down one line. If the cursor was on the bottom line of the text viewport, the viewport scrolls up. The cursor is constrained to remain within the text viewport.
void vdc_cursor_down(void);

// Prints a character on the display and advances the cursor.
void vdc_put_char(char c);

// Prints NUL-terminated string on the display.
void vdc_put_string(char* s);
